@@ -23,6 +23,7 @@ namespace SourceGit.ViewModels
 
                 _instance.PrepareGit();
                 _instance.PrepareShellOrTerminal();
+                _instance.PrepareExternalDiffMergeTool();
                 _instance.PrepareWorkspaces();
 
                 return _instance;
@@ -344,12 +345,12 @@ namespace SourceGit.ViewModels
             }
         }
 
-        public int ShellOrTerminal
+        public int ShellOrTerminalType
         {
-            get => _shellOrTerminal;
+            get => _shellOrTerminalType;
             set
             {
-                if (SetProperty(ref _shellOrTerminal, value))
+                if (SetProperty(ref _shellOrTerminalType, value) && !_isLoading)
                 {
                     if (value >= 0 && value < Models.ShellOrTerminal.Supported.Count)
                         Native.OS.SetShellOrTerminal(Models.ShellOrTerminal.Supported[value]);
@@ -357,6 +358,7 @@ namespace SourceGit.ViewModels
                         Native.OS.SetShellOrTerminal(null);
 
                     OnPropertyChanged(nameof(ShellOrTerminalPath));
+                    OnPropertyChanged(nameof(ShellOrTerminalArgs));
                 }
             }
         }
@@ -374,6 +376,19 @@ namespace SourceGit.ViewModels
             }
         }
 
+        public string ShellOrTerminalArgs
+        {
+            get => Native.OS.ShellOrTerminalArgs;
+            set
+            {
+                if (value != Native.OS.ShellOrTerminalArgs)
+                {
+                    Native.OS.ShellOrTerminalArgs = value;
+                    OnPropertyChanged();
+                }
+            }
+        }
+
         public int ExternalMergeToolType
         {
             get => Native.OS.ExternalMergerType;
@@ -388,6 +403,8 @@ namespace SourceGit.ViewModels
                     {
                         Native.OS.AutoSelectExternalMergeToolExecFile();
                         OnPropertyChanged(nameof(ExternalMergeToolPath));
+                        OnPropertyChanged(nameof(ExternalMergeToolDiffArgs));
+                        OnPropertyChanged(nameof(ExternalMergeToolMergeArgs));
                     }
                 }
             }
@@ -406,6 +423,32 @@ namespace SourceGit.ViewModels
             }
         }
 
+        public string ExternalMergeToolDiffArgs
+        {
+            get => Native.OS.ExternalDiffArgs;
+            set
+            {
+                if (!Native.OS.ExternalDiffArgs.Equals(value, StringComparison.Ordinal))
+                {
+                    Native.OS.ExternalDiffArgs = value;
+                    OnPropertyChanged();
+                }
+            }
+        }
+
+        public string ExternalMergeToolMergeArgs
+        {
+            get => Native.OS.ExternalMergeArgs;
+            set
+            {
+                if (!Native.OS.ExternalMergeArgs.Equals(value, StringComparison.Ordinal))
+                {
+                    Native.OS.ExternalMergeArgs = value;
+                    OnPropertyChanged();
+                }
+            }
+        }
+
         public uint StatisticsSampleColor
         {
             get => _statisticsSampleColor;
@@ -602,7 +645,7 @@ namespace SourceGit.ViewModels
 
         private void PrepareShellOrTerminal()
         {
-            if (_shellOrTerminal >= 0)
+            if (_shellOrTerminalType >= 0)
                 return;
 
             for (int i = 0; i < Models.ShellOrTerminal.Supported.Count; i++)
@@ -610,12 +653,25 @@ namespace SourceGit.ViewModels
                 var shell = Models.ShellOrTerminal.Supported[i];
                 if (Native.OS.TestShellOrTerminal(shell))
                 {
-                    ShellOrTerminal = i;
+                    ShellOrTerminalType = i;
                     break;
                 }
             }
         }
 
+        private void PrepareExternalDiffMergeTool()
+        {
+            var mergerType = Native.OS.ExternalMergerType;
+            if (mergerType > 0 && mergerType < Models.ExternalMerger.Supported.Count)
+            {
+                var merger = Models.ExternalMerger.Supported[mergerType];
+                if (string.IsNullOrEmpty(Native.OS.ExternalDiffArgs))
+                    Native.OS.ExternalDiffArgs = merger.DiffCmd;
+                if (string.IsNullOrEmpty(Native.OS.ExternalMergeArgs))
+                    Native.OS.ExternalMergeArgs = merger.MergeCmd;
+            }
+        }
+
         private void PrepareWorkspaces()
         {
             if (Workspaces.Count == 0)
@@ -747,7 +803,7 @@ namespace SourceGit.ViewModels
         private Models.ChangeViewMode _stashChangeViewMode = Models.ChangeViewMode.List;
 
         private string _gitDefaultCloneDir = string.Empty;
-        private int _shellOrTerminal = -1;
+        private int _shellOrTerminalType = -1;
         private uint _statisticsSampleColor = 0xFF00FF00;
     }
 }
