@@ -28,10 +28,8 @@ namespace SourceGit.ViewModels
 
     public class TextDiffContext : ObservableObject
     {
+        public Models.DiffOption Option => _option;
         public Models.TextDiff Data => _data;
-        public string File => _data.File;
-        public bool IsUnstaged => _data.Option.IsUnstaged;
-        public bool EnableChunkOption => _data.Option.WorkingCopyChange != null;
 
         public Vector ScrollOffset
         {
@@ -132,6 +130,33 @@ namespace SourceGit.ViewModels
             return null;
         }
 
+        protected void TryKeepPrevState(TextDiffContext prev, List<Models.TextDiffLine> lines)
+        {
+            var fastTest = prev != null &&
+                prev._option.IsUnstaged == _option.IsUnstaged &&
+                prev._option.Path.Equals(_option.Path, StringComparison.Ordinal) &&
+                prev._option.OrgPath.Equals(_option.OrgPath, StringComparison.Ordinal) &&
+                prev._option.Revisions.Count == _option.Revisions.Count;
+
+            if (!fastTest)
+            {
+                _blockNavigation = new BlockNavigation(lines, 0);
+                return;
+            }
+
+            for (int i = 0; i < _option.Revisions.Count; i++)
+            {
+                if (!prev._option.Revisions[i].Equals(_option.Revisions[i], StringComparison.Ordinal))
+                {
+                    _blockNavigation = new BlockNavigation(lines, 0);
+                    return;
+                }
+            }
+
+            _blockNavigation = new BlockNavigation(lines, prev._blockNavigation.GetCurrentBlockIndex());
+        }
+
+        protected Models.DiffOption _option = null;
         protected Models.TextDiff _data = null;
         protected Vector _scrollOffset = Vector.Zero;
         protected BlockNavigation _blockNavigation = null;
@@ -142,24 +167,17 @@ namespace SourceGit.ViewModels
 
     public class CombinedTextDiff : TextDiffContext
     {
-        public CombinedTextDiff(Models.TextDiff diff, CombinedTextDiff previous = null)
+        public CombinedTextDiff(Models.DiffOption option, Models.TextDiff diff, TextDiffContext previous = null)
         {
+            _option = option;
             _data = diff;
 
-            if (previous != null && previous.File.Equals(File, StringComparison.Ordinal))
-            {
-                _blockNavigation = new BlockNavigation(_data.Lines, false);
-                _scrollOffset = previous._scrollOffset;
-            }
-            else
-            {
-                _blockNavigation = new BlockNavigation(_data.Lines, true);
-            }
+            TryKeepPrevState(previous, _data.Lines);
         }
 
         public override TextDiffContext SwitchMode()
         {
-            return new TwoSideTextDiff(_data);
+            return new TwoSideTextDiff(_option, _data, this);
         }
     }
 
@@ -168,8 +186,9 @@ namespace SourceGit.ViewModels
         public List<Models.TextDiffLine> Old { get; } = [];
         public List<Models.TextDiffLine> New { get; } = [];
 
-        public TwoSideTextDiff(Models.TextDiff diff, TwoSideTextDiff previous = null)
+        public TwoSideTextDiff(Models.DiffOption option, Models.TextDiff diff, TextDiffContext previous = null)
         {
+            _option = option;
             _data = diff;
 
             foreach (var line in diff.Lines)
@@ -191,16 +210,7 @@ namespace SourceGit.ViewModels
             }
 
             FillEmptyLines();
-
-            if (previous != null && previous.File.Equals(File, StringComparison.Ordinal))
-            {
-                _blockNavigation = new BlockNavigation(_data.Lines, false);
-                _scrollOffset = previous._scrollOffset;
-            }
-            else
-            {
-                _blockNavigation = new BlockNavigation(_data.Lines, true);
-            }
+            TryKeepPrevState(previous, Old);
         }
 
         public override bool IsSideBySide()
@@ -210,7 +220,7 @@ namespace SourceGit.ViewModels
 
         public override TextDiffContext SwitchMode()
         {
-            return new CombinedTextDiff(_data);
+            return new CombinedTextDiff(_option, _data, this);
         }
 
         public void ConvertsToCombinedRange(ref int startLine, ref int endLine, bool isOldSide)
