@@ -370,6 +370,8 @@ namespace SourceGit.Views
             if (sender is Button button && DataContext is ViewModels.WorkingCopy vm && ShowAdvancedOptions)
             {
                 var repo = vm.Repository;
+                var foreground = this.FindResource("Brush.FG1") as IBrush;
+
                 var menu = new ContextMenu();
                 menu.MaxWidth = 480;
 
@@ -388,10 +390,13 @@ namespace SourceGit.Views
                 {
                     for (int i = 0; i < templateCount; i++)
                     {
+                        var icon = App.CreateMenuIcon("Icons.Code");
+                        icon.Fill = foreground;
+
                         var template = repo.Settings.CommitTemplates[i];
                         var item = new MenuItem();
                         item.Header = App.Text("WorkingCopy.UseCommitTemplate", template.Name);
-                        item.Icon = App.CreateMenuIcon("Icons.Code");
+                        item.Icon = icon;
                         item.Click += (_, ev) =>
                         {
                             vm.ApplyCommitMessageTemplate(template);
@@ -414,9 +419,12 @@ namespace SourceGit.Views
                                 friendlyName = $"~{gitTemplate.AsSpan(prefixLen)}";
                         }
 
+                        var icon = App.CreateMenuIcon("Icons.Code");
+                        icon.Fill = foreground;
+
                         var gitTemplateItem = new MenuItem();
                         gitTemplateItem.Header = App.Text("WorkingCopy.UseCommitTemplate", friendlyName);
-                        gitTemplateItem.Icon = App.CreateMenuIcon("Icons.Code");
+                        gitTemplateItem.Icon = icon;
                         gitTemplateItem.Click += (_, ev) =>
                         {
                             if (File.Exists(gitTemplate))
@@ -451,9 +459,12 @@ namespace SourceGit.Views
                             TextTrimming = TextTrimming.CharacterEllipsis
                         };
 
+                        var icon = App.CreateMenuIcon("Icons.Histories");
+                        icon.Fill = foreground;
+
                         var item = new MenuItem();
                         item.Header = header;
-                        item.Icon = App.CreateMenuIcon("Icons.Histories");
+                        item.Icon = icon;
                         item.Click += (_, ev) =>
                         {
                             vm.CommitMessage = dup;
@@ -465,9 +476,12 @@ namespace SourceGit.Views
 
                     menu.Items.Add(new MenuItem() { Header = "-" });
 
+                    var clearIcon = App.CreateMenuIcon("Icons.Clear");
+                    clearIcon.Fill = foreground;
+
                     var clearHistoryItem = new MenuItem();
                     clearHistoryItem.Header = App.Text("WorkingCopy.ClearCommitHistories");
-                    clearHistoryItem.Icon = App.CreateMenuIcon("Icons.Clear");
+                    clearHistoryItem.Icon = clearIcon;
                     clearHistoryItem.Click += async (_, ev) =>
                     {
                         await vm.ClearCommitMessageHistoryAsync();
@@ -477,7 +491,9 @@ namespace SourceGit.Views
                     menu.Items.Add(clearHistoryItem);
                 }
 
+                button.IsEnabled = false;
                 menu.Placement = PlacementMode.TopEdgeAlignedLeft;
+                menu.Closed += (o, ev) => button.IsEnabled = true;
                 menu.Open(button);
             }
 
@@ -486,7 +502,7 @@ namespace SourceGit.Views
 
         private async void OnOpenOpenAIHelper(object sender, RoutedEventArgs e)
         {
-            if (DataContext is ViewModels.WorkingCopy vm && sender is Control control && ShowAdvancedOptions)
+            if (DataContext is ViewModels.WorkingCopy vm && sender is Button button && ShowAdvancedOptions)
             {
                 var repo = vm.Repository;
 
@@ -505,11 +521,11 @@ namespace SourceGit.Views
 
                 if (services.Count == 1)
                 {
-                    await App.ShowDialog(new ViewModels.AIAssistant(repo, services[0], vm.Staged, t => vm.CommitMessage = t));
+                    await App.ShowDialog(new ViewModels.AIAssistant(repo, services[0], vm.Staged));
                     return;
                 }
 
-                var menu = new ContextMenu() { Placement = PlacementMode.TopEdgeAlignedLeft };
+                var menu = new ContextMenu();
                 foreach (var service in services)
                 {
                     var dup = service;
@@ -517,13 +533,17 @@ namespace SourceGit.Views
                     item.Header = service.Name;
                     item.Click += async (_, ev) =>
                     {
-                        await App.ShowDialog(new ViewModels.AIAssistant(repo, dup, vm.Staged, t => vm.CommitMessage = t));
+                        await App.ShowDialog(new ViewModels.AIAssistant(repo, dup, vm.Staged));
                         ev.Handled = true;
                     };
 
                     menu.Items.Add(item);
                 }
-                menu.Open(control);
+
+                button.IsEnabled = false;
+                menu.Placement = PlacementMode.TopEdgeAlignedLeft;
+                menu.Closed += (o, ev) => button.IsEnabled = true;
+                menu.Open(button);
             }
 
             e.Handled = true;
