@@ -559,10 +559,21 @@ namespace SourceGit.Views
                     squash.IsEnabled = commit.Parents.Count == 1;
                     squash.Click += async (_, e) =>
                     {
-                        await vm.SquashHeadAsync(commit);
+                        await vm.SquashOrFixupHeadAsync(commit, false);
                         e.Handled = true;
                     };
                     menu.Items.Add(squash);
+
+                    var fixup = new MenuItem();
+                    fixup.Header = App.Text("CommitCM.Fixup");
+                    fixup.Icon = App.CreateMenuIcon("Icons.Fix");
+                    fixup.IsEnabled = commit.Parents.Count == 1;
+                    fixup.Click += async (_, e) =>
+                    {
+                        await vm.SquashOrFixupHeadAsync(commit, true);
+                        e.Handled = true;
+                    };
+                    menu.Items.Add(fixup);
                 }
                 else
                 {
