@@ -248,7 +248,7 @@ namespace SourceGit.Views
                     histories.Icon = App.CreateMenuIcon("Icons.Histories");
                     histories.Click += (_, ev) =>
                     {
-                        App.ShowWindow(new ViewModels.FileHistories(repo, submodule.Path));
+                        App.ShowWindow(new ViewModels.FileHistories(repo.FullPath, submodule.Path));
                         ev.Handled = true;
                     };
 
