@@ -890,7 +890,7 @@ namespace SourceGit.Views
                 {
                     ai.Click += async (_, e) =>
                     {
-                        await App.ShowDialog(new ViewModels.AIAssistant(repo, services[0], selectedStaged, t => vm.CommitMessage = t));
+                        await App.ShowDialog(new ViewModels.AIAssistant(repo, services[0], selectedStaged));
                         e.Handled = true;
                     };
                 }
@@ -904,7 +904,7 @@ namespace SourceGit.Views
                         item.Header = service.Name;
                         item.Click += async (_, e) =>
                         {
-                            await App.ShowDialog(new ViewModels.AIAssistant(repo, dup, selectedStaged, t => vm.CommitMessage = t));
+                            await App.ShowDialog(new ViewModels.AIAssistant(repo, dup, selectedStaged));
                             e.Handled = true;
                         };
 
